==> jc-1.4.0.tar.gz: soot/toolkits/scalar/BranchedFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.BranchedFlowAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowAnalysis

#include "soot/toolkits/scalar/AbstractFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$flowThrough$cc434845b7f2ea5b(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getBranchFlowAfter$e38cedb7c64e4cf5(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getFallFlowAfter$55792112bd17ad30(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getFlowBefore$23479f4d09606ef9(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$flowThrough$cc434845b7f2ea5b;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getBranchFlowAfter$e38cedb7c64e4cf5;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getFallFlowAfter$55792112bd17ad30;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getFlowBefore$23479f4d09606ef9;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods {
	void	(*flowThrough$cc434845b7f2ea5b)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
	struct _jc_object	*(*getBranchFlowAfter$e38cedb7c64e4cf5)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*getFallFlowAfter$55792112bd17ad30)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*getFlowBefore$23479f4d09606ef9)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs {
	struct _jc_object	*unitToAfterFallFlow;
	struct _jc_object	*unitToAfterBranchFlow;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object {
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype _jc_soot_toolkits_scalar_BranchedFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_BranchedFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_BranchedFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/BranchedFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.BranchedFlowAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class 6279fcb5fd9bedca soot_toolkits_scalar_BranchedFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_AbstractFlowAnalysis

#include "soot/toolkits/scalar/AbstractFlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$flowThrough$cc434845b7f2ea5b(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getBranchFlowAfter$e38cedb7c64e4cf5(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getFallFlowAfter$55792112bd17ad30(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_toolkits_scalar_BranchedFlowAnalysis$method$getFlowBefore$23479f4d09606ef9(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$flowThrough$cc434845b7f2ea5b;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getBranchFlowAfter$e38cedb7c64e4cf5;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getFallFlowAfter$55792112bd17ad30;
extern _jc_method _jc_soot_toolkits_scalar_BranchedFlowAnalysis$method_info$getFlowBefore$23479f4d09606ef9;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods {
	void	(*flowThrough$cc434845b7f2ea5b)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getBranchFlowAfter$e38cedb7c64e4cf5)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getFallFlowAfter$55792112bd17ad30)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getFlowBefore$23479f4d09606ef9)(_jc_env *, struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vmethods	soot_toolkits_scalar_BranchedFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs {
	struct _jc_object	*unitToAfterFallFlow;
	struct _jc_object	*unitToAfterBranchFlow;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_refs	soot_toolkits_scalar_BranchedFlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_BranchedFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_BranchedFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_BranchedFlowAnalysis$object {
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_BranchedFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_BranchedFlowAnalysis$vtype _jc_soot_toolkits_scalar_BranchedFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_BranchedFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_BranchedFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_BranchedFlowAnalysis_H_ */
